# groundplex

[![pipeline status](https://gitlab.com/arden-puppet/arden-groundplex/badges/0.2.0-r1/pipeline.svg)](https://gitlab.com/arden-puppet/arden-groundplex/commits/0.2.0-r1) [![Version](https://img.shields.io/puppetforge/v/arden/groundplex.svg)](https://forge.puppet.com/arden/groundplex) [![coverage report](https://gitlab.com/arden-puppet/arden-groundplex/badges/0.2.0-r1/coverage.svg)](https://gitlab.com/arden-puppet/arden-groundplex/commits/0.2.0-r1)

## Table of Contents

1. [Description](#description)
1. [Setup - The basics of getting started with groundplex](#setup)
    * [What groundplex affects](#what-groundplex-affects)
    * [Setup requirements](#setup-requirements)
    * [Beginning with groundplex](#beginning-with-groundplex)
1. [Usage - Configuration options and additional functionality](#usage)
1. [Limitations - OS compatibility, etc.](#limitations)
1. [Development - Guide for contributing to the module](#development)

## Description

This module installs and configures the Snaplogic Sidekick module on the current node. It also provides a baseline configuration for SAP connectivity and makes managing the additional service definitions relatively trivial.

## Setup

### What groundplex affects

Primarily does the following:

* Installs the snaplogic-sidecar
* Downloads and places the slpropgz file from your Snaplogic Organization
* Adds appropriate entries into `/etc/services` to support connections to SAP instances

### Setup Requirements

You'll need to have the following components configured:
* snaplogic-sidekick package must be available to the node via your package manager

The following two puppet modules are also dependencies, however, the needed versions are not currently available on puppet forge.
* [sap](https://gitlab.com/pdemon/puppet-sap) - needed for some type alias definitions
* [etc_services](https://github.com/pdemonaco/puppet-etc_services) - relevant for syntax changes introduced by this version

#### SAP Java Connector (Deprecated)

This process is no-longer needed as the Java Connector is bundled into the package.

1. Download the latest version of the [SAP Java Connector](https://support.sap.com/en/product/connectors/jco.html)
from their website
1. Extract the archive and host the files `libsapjco3.jnilib` and `libsapjco3.so` on your puppetmaster or a server your nodes can reach easily.
1. Calculate the checksums of each file and provide both the source URL and the checksum to the groundplex class.

##### See Also

* [Groundplex Requirements](https://docs-snaplogic.atlassian.net/wiki/spaces/SD/pages/1438296/Groundplex+Requirements)
* [SnapPlex JCO Configuration](https://docs-snaplogic.atlassian.net/wiki/spaces/SD/pages/1438398/Configuring%2BSAP%2BAccounts)

Also, if using SAP Java Connections consider deploying niping to your node for testing purposes.

### Beginning with groundplex

The following puppet code defines a node as a standard execution engine (JCC).

```puppet
class { 'groundplex':
  slpropz_source => 'https://elastic.snaplogic.com/api/1/rest/plex/config/ExampleOrg/shared/Example?expires=1623084093&user_id=someuser%40example.com&_sl_authproxy_key=SomeRandomTokenStuff
  server_type    => 'JCC',
}
```

## Usage

Puppet configuration including SAP connection definitions.

```puppet
class { 'groundplex':
  slpropz_source    => 'https://elastic.snaplogic.com/api/1/rest/plex/config/ExampleOrg/shared/Example?expires=1623084093&user_id=someuser%40example.com&_sl_authproxy_key=SomeRandomTokenStuff'
  server_type       => 'JCC',
  array_msg_servers => [
    {
      sid            => 'DEV',
      instance_class => 'cs-abap',
      number         => '01',
    },
    {
      sid            => 'QAS',
      instance_class => 'cs-abap',
      number         => '01',
    },
    {
      sid            => 'PRD',
      instance_class => 'cs-abap',
      number         => '01',
    },
  ],
}
```

Hiera configuration including SAP connection definitions.

```puppet
groundplex::slpropz_source: 'https://elastic.snaplogic.com/api/1/rest/plex/config/ExampleOrg/shared/Example?expires=1623084093&user_id=someuser%40example.com&_sl_authproxy_key=SomeRandomTokenStuff'
groundplex::server_type: 'JCC'
groundplex::array_msg_servers:
  - sid: 'DEV'
    instance_class: 'cs-abap'
    number: '01'
  - sid: 'QAS'
    instance_class: 'cs-abap'
    number: '01'
  - sid: 'PRD'
    instance_class: 'cs-abap'
    number: '01'
```

## Limitations

Currently only tested on RHEL/CentOS/Rocky 7 and 8.

## Development

Make a pull request and we'll figure it out!
