# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`groundplex`](#groundplex): Configures a Snaplogic on-premise execution engine.
* [`groundplex::config`](#groundplex--config): Performs zone creation and update operations. Internal class
* [`groundplex::install`](#groundplex--install): Install the snaplogic-sidekick package
* [`groundplex::service`](#groundplex--service): Internal class which ensures the groundplex process is running

### Data types

* [`Groundplex::PackageVersion`](#Groundplex--PackageVersion): Specifies the installation mode of the package
* [`Groundplex::PuppetUrl`](#Groundplex--PuppetUrl): Matches puppet:// paths
* [`Groundplex::SapMessageServer`](#Groundplex--SapMessageServer)
* [`Groundplex::Sapjco3Config`](#Groundplex--Sapjco3Config): Content definitions for SAP Java Connector library files.
* [`Groundplex::ServerType`](#Groundplex--ServerType): List of valid items to specify in /etc/security/limits.conf
* [`Groundplex::SourceUrl`](#Groundplex--SourceUrl): matches any valid URL type

## Classes

### <a name="groundplex"></a>`groundplex`

Configures a Snaplogic on-premise execution engine.

#### Parameters

The following parameters are available in the `groundplex` class:

* [`service_user`](#-groundplex--service_user)
* [`service_group`](#-groundplex--service_group)
* [`server_type`](#-groundplex--server_type)
* [`slpropz_source`](#-groundplex--slpropz_source)
* [`package`](#-groundplex--package)
* [`array_msg_servers`](#-groundplex--array_msg_servers)
* [`sapjco_config`](#-groundplex--sapjco_config)

##### <a name="-groundplex--service_user"></a>`service_user`

Data type: `String`

Username of the snaplogic service account.
Note that this is created by the installation of the agent RPM.

Default value: `'snapuser'`

##### <a name="-groundplex--service_group"></a>`service_group`

Data type: `String`

Group name of the snaplogic service user
Note that this is created by the installation of the agent RPM.

Default value: `'snapuser'`

##### <a name="-groundplex--server_type"></a>`server_type`

Data type: `Groundplex::ServerType`

Determines the role this node will perform in the on-premise environment.
Currently this is limited to the following:
  - `JCC` - An execution engine node which performs actual pipeline work
  - `FeedMaster` - Manages the data feed for Ultra Pipelines

Default value: `'JCC'`

##### <a name="-groundplex--slpropz_source"></a>`slpropz_source`

Data type: `Stdlib::HTTPSUrl`

Full URL including API parameters to the snaplogic configuration file
associated with this snaplex. This is retrieved from the Downloads tab of
the Snaplex Settings dialog in Manager -> Project Spaces -> shared ->
Snaplexes.

##### <a name="-groundplex--package"></a>`package`

Data type: `String`

Name of the snaplogic agent package. Note that this assumes the presence of
a custom repo / mirror which also hosts this file.

Default value: `'snaplogic-sidekick'`

##### <a name="-groundplex--array_msg_servers"></a>`array_msg_servers`

Data type: `Array[Groundplex::SapMessageserver]`

List of SAP ms server intances which should be added to the
/etc/services file on this groundplex host.

Default value: `[]`

##### <a name="-groundplex--sapjco_config"></a>`sapjco_config`

Data type: `Optional[Groundplex::Sapjco3Config]`

When provided, this overrides the default bundled version of SAPJCo with a
different version. See the type definition for detail.

Default value: `undef`

### <a name="groundplex--config"></a>`groundplex::config`

Performs zone creation and update operations. Internal class

#### Parameters

The following parameters are available in the `groundplex::config` class:

* [`server_type`](#-groundplex--config--server_type)
* [`service_user`](#-groundplex--config--service_user)
* [`service_group`](#-groundplex--config--service_group)
* [`slpropz_source`](#-groundplex--config--slpropz_source)
* [`array_msg_servers`](#-groundplex--config--array_msg_servers)

##### <a name="-groundplex--config--server_type"></a>`server_type`

Data type: `Groundplex::ServerType`

Controls whether this node is setup as a execution engine, or a feedmaster.

Default value: `$groundplex::server_type`

##### <a name="-groundplex--config--service_user"></a>`service_user`

Data type: `String`

Account which runs the groundplex engine.

Default value: `$groundplex::service_user`

##### <a name="-groundplex--config--service_group"></a>`service_group`

Data type: `String`

Primary group of the account which runs the groundplex engine.

Default value: `$groundplex::service_group`

##### <a name="-groundplex--config--slpropz_source"></a>`slpropz_source`

Data type: `Stdlib::HTTPSUrl`

Source from which the config file is downloaded initially. Note that this
URL has an authentication component and currently can't be automatically
refreshed.

Default value: `$groundplex::slpropz_source`

##### <a name="-groundplex--config--array_msg_servers"></a>`array_msg_servers`

Data type: `Array[Groundplex::SapMessageServer]`

List of SAP message servers which are allowed to connect to this snaplogic
instance. These are primarily used to create entries in /etc/services

Default value: `$groundplex::array_msg_servers`

### <a name="groundplex--install"></a>`groundplex::install`

Install the snaplogic-sidekick package

#### Parameters

The following parameters are available in the `groundplex::install` class:

* [`package`](#-groundplex--install--package)
* [`service_user`](#-groundplex--install--service_user)
* [`service_group`](#-groundplex--install--service_group)
* [`sapjco_config`](#-groundplex--install--sapjco_config)
* [`package_version`](#-groundplex--install--package_version)

##### <a name="-groundplex--install--package"></a>`package`

Data type: `String`

Name of the RPM package needed to install the groundplex sidekick

Default value: `$groundplex::package`

##### <a name="-groundplex--install--service_user"></a>`service_user`

Data type: `String`

Account which owns the groundplex files.

Default value: `$groundplex::service_user`

##### <a name="-groundplex--install--service_group"></a>`service_group`

Data type: `String`

Primary group of the account which owns the files.

Default value: `$groundplex::service_group`

##### <a name="-groundplex--install--sapjco_config"></a>`sapjco_config`

Data type: `Optional[Groundplex::Sapjco3Config]`

When provided, this overrides the libsapjco3.so file that is included in
Snaplogic by default.

Default value: `undef`

##### <a name="-groundplex--install--package_version"></a>`package_version`

Data type: `Groundplex::PackageVersion`

When specified this value controlles the version of the package deployed to
the server. The default value ensures it is installed but will not
automatically update it.

Default value: `'present'`

### <a name="groundplex--service"></a>`groundplex::service`

Internal class which ensures the groundplex process is running

## Data types

### <a name="Groundplex--PackageVersion"></a>`Groundplex::PackageVersion`

Specifies the installation mode of the package

Alias of `Enum['present', 'latest']`

### <a name="Groundplex--PuppetUrl"></a>`Groundplex::PuppetUrl`

Matches puppet:// paths

Alias of `Pattern[/(?i:^puppet?:\/\/)/]`

### <a name="Groundplex--SapMessageServer"></a>`Groundplex::SapMessageServer`

The Groundplex::SapMessageServer data type.

Alias of

```puppet
Struct[sid                     => Sap::SID,
  instance_class          => Sap::InstClassSapCs,
  number                  => Sap::InstNumber,
  Optional[port_override] => Stdlib::Port]
```

#### Parameters

The following parameters are available in the `Groundplex::SapMessageServer` data type:

* [`sid`](#-Groundplex--SapMessageServer--sid)
* [`instance_class`](#-Groundplex--SapMessageServer--instance_class)
* [`number`](#-Groundplex--SapMessageServer--number)
* [`port_override`](#-Groundplex--SapMessageServer--port_override)

##### <a name="-Groundplex--SapMessageServer--sid"></a>`sid`

Matches an SAP instance number

##### <a name="-Groundplex--SapMessageServer--instance_class"></a>`instance_class`

Used to determine the port set to use for the instance alias

##### <a name="-Groundplex--SapMessageServer--number"></a>`number`

Two digit instance number (e.g. 01) which is appended to the port prefix
determined from the instance class.

##### <a name="-Groundplex--SapMessageServer--port_override"></a>`port_override`

Used in exceptional cases to override the port calculation

### <a name="Groundplex--Sapjco3Config"></a>`Groundplex::Sapjco3Config`

Content definitions for SAP Java Connector library files.

Alias of

```puppet
Struct[source => Groundplex::SourceURL,
  sha256 => Pattern[/\h{64}/]]
```

#### Parameters

The following parameters are available in the `Groundplex::Sapjco3Config` data type:

* [`source`](#-Groundplex--Sapjco3Config--source)
* [`sha256`](#-Groundplex--Sapjco3Config--sha256)

##### <a name="-Groundplex--Sapjco3Config--source"></a>`source`

Some form of URL to a copy of the libsapjco3.so library.

##### <a name="-Groundplex--Sapjco3Config--sha256"></a>`sha256`

A sha256 hash matching the content of the file referenced by $source.

### <a name="Groundplex--ServerType"></a>`Groundplex::ServerType`

List of valid items to specify in /etc/security/limits.conf

Alias of `Enum['JCC', 'FeedMaster']`

### <a name="Groundplex--SourceUrl"></a>`Groundplex::SourceUrl`

matches any valid URL type

Alias of `Variant[Stdlib::Httpurl, Stdlib::Httpsurl, Groundplex::PuppetUrl]`

