# @param service_user
#   Username of the snaplogic service account.
#   Note that this is created by the installation of the agent RPM.
#
# @param service_group
#   Group name of the snaplogic service user
#   Note that this is created by the installation of the agent RPM.
#
# @param server_type
#   Determines the role this node will perform in the on-premise environment.
#   Currently this is limited to the following:
#     - `JCC` - An execution engine node which performs actual pipeline work
#     - `FeedMaster` - Manages the data feed for Ultra Pipelines
#
# @param slpropz_source
#   Full URL including API parameters to the snaplogic configuration file
#   associated with this snaplex. This is retrieved from the Downloads tab of
#   the Snaplex Settings dialog in Manager -> Project Spaces -> shared ->
#   Snaplexes.
#
# @param package
#   Name of the snaplogic agent package. Note that this assumes the presence of
#   a custom repo / mirror which also hosts this file.
#
# @param array_msg_servers
#   List of SAP ms server intances which should be added to the 
#   /etc/services file on this groundplex host.
#
# @param sapjco_config
#   When provided, this overrides the default bundled version of SAPJCo with a
#   different version. See the type definition for detail.
#
# @summary Configures a Snaplogic on-premise execution engine.
class groundplex (
  Stdlib::HTTPSUrl $slpropz_source,
  Array[Groundplex::SapMessageserver] $array_msg_servers = [],
  Groundplex::ServerType $server_type                    = 'JCC',
  String $service_user                                   = 'snapuser',
  String $service_group                                  = 'snapuser',
  String $package                                        = 'snaplogic-sidekick',
  Optional[Groundplex::Sapjco3Config] $sapjco_config     = undef,
) {
  class { 'groundplex::install':
    package       => $package,
    sapjco_config => $sapjco_config,
  }
  contain 'groundplex::install'
  contain 'groundplex::config'
  contain 'groundplex::service'

  Class['groundplex::install']
  -> Class['groundplex::config']
  ~> Class['groundplex::service']
}
