# @param package
#   Name of the RPM package needed to install the groundplex sidekick
#
# @param service_user
#   Account which owns the groundplex files.
#
# @param service_group
#   Primary group of the account which owns the files.
#
# @param sapjco_config
#   When provided, this overrides the libsapjco3.so file that is included in
#   Snaplogic by default.
#
# @param package_version
#   When specified this value controlles the version of the package deployed to
#   the server. The default value ensures it is installed but will not
#   automatically update it.
# 
# @summary Install the snaplogic-sidekick package
class groundplex::install (
  String $package                                    = $groundplex::package,
  String $service_user                               = $groundplex::service_user,
  String $service_group                              = $groundplex::service_group,
  Optional[Groundplex::Sapjco3Config] $sapjco_config = undef,
  Groundplex::PackageVersion $package_version        = 'present',
) {
  package { $package:
    ensure => $package_version,
  }

  # TODO - configure based on the init system in place on this node
  file { '/etc/systemd/system/snaplogic.service':
    ensure  => 'file',
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => file('groundplex/snaplogic.service'),
  }

  include limits
  include firewalld

  if $sapjco_config {
    file { '/opt/snaplogic/ldlib/libsapjco3.so':
      ensure         => 'file',
      owner          => $service_user,
      group          => $service_group,
      mode           => '0755',
      source         => $sapjco_config['source'],
      checksum       => 'sha256',
      checksum_value => $sapjco_config['sha256'],
      require        => Package[$package],
    }
  }
}
